@@ -316,6 +316,34 @@ if(isset($_GET['action'])) {
 		sendto_xchanged($send);
 		WriteSuccessMsg("<br><li>The commond is sended to Server.</li>","?bank_name=$_REQUEST[bank_name]&group_id=$_REQUEST[group_id]&order=$order_type&order_key=$order_key");
 	}
+	else if($action=="set_imei_db"){
+		$where=gen_sim_where();
+		
+		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
+		$num=$db->num_rows($query);
+		$query0=$db->query("select id,imei from imei_db order by used limit $num");
+		while($row0=$db->fetch_array($query0)) {
+			$imei_db[]=$row0;
+		}
+		$i=0;
+		while($row=$db->fetch_array($query)) {
+			if($imei_db[$i]){
+				$row['imei_mode']==2;
+				$row['imei']=$imei_db[$i]['imei'];
+				$imei_db[$i]['sim_name']=$row['sim_name'];
+				$log.="<br>SIM Slot:$row[sim_name] Set IMEI:$row[imei]";
+				$send[]=my_pack($row, SIM_ADD);
+				$db->query("update imei_db set sim_name='$row[sim_name]',used=used+1,used_time=now() where id=".$imei_db[$i]['id']);
+				$db->query("update sim set imei_mode=2, imei='$row[imei]' where id=$row[id]");
+			}
+			else {
+				$log.="<br>SIM Slot:$row[sim_name] not find IMEI from database";
+			}
+			$i++;
+		}
+		sendto_xchanged($send);
+		WriteSuccessMsg("<br><li>The commond is sended to Server.$log</li>","?bank_name=$_REQUEST[bank_name]&group_id=$_REQUEST[group_id]&order=$order_type&order_key=$order_key");
+	}
 	else $action="main";
 
 	}
